@@ -1,6 +1,6 @@
 package CHI::Driver;
 BEGIN {
-  $CHI::Driver::VERSION = '0.42';
+  $CHI::Driver::VERSION = '0.43';
 }
 use Carp;
 use CHI::CacheObject;
@@ -29,6 +29,7 @@ my $default_key_serializer = CHI::Serializer::JSON->new();
 my $default_key_digester   = Digest::MD5->new();
 
 has 'chi_root_class'     => ( is => 'ro' );
+has 'compress_threshold' => ( is => 'ro', isa => 'Int' );
 has 'constructor_params' => ( is => 'ro', init_arg => undef );
 has 'driver_class'       => ( is => 'ro' );
 has 'expires_at'         => ( is => 'rw', default => CHI_Max_Time );
@@ -309,7 +310,8 @@ sub set_with_options {
     #
     my $obj =
       $self->cache_object_class->new( $key, $value, $created_at,
-        $early_expires_at, $expires_at, $self->serializer );
+        $early_expires_at, $expires_at, $self->serializer,
+        $self->compress_threshold );
     if ( defined( my $obj_ref = $options->{obj_ref} ) ) {
         $$obj_ref = $obj;
     }
@@ -641,7 +643,7 @@ CHI::Driver - Base class for all CHI drivers
 
 =head1 VERSION
 
-version 0.42
+version 0.43
 
 =head1 DESCRIPTION
 
